@@ -5,13 +5,10 @@
 #'
 #' The CAS number is matched for each VOC speices (from column name), and the
 #' Maximum Incremental Reactivity (MIR) value is matched through the CAS number and used for time series calculation. \cr
-#' The MIR value comes from "Carter, W. P. (2009). Updated maximum incremental
-#' reactivity scale and hydrocarbon bin reactivities for regulatory applications.
-#' California Air Resources Board Contract, 2009, 339" (revised January 28, 2010).
-#' Note: If input VOC species contain M,P-xylene, it will be automatically divided into m-xylene and P-xylene evenly.
+#' The MIR value comes from <https://ww2.arb.ca.gov/sites/default/files/classic/regact/2009/mir2009/mir10.pdf>, 
+#' Zhang et al.(2021) <doi:10.5194/acp-21-11053-2021>.
 #'
 #' @param df dataframe contains time series.
-#' @param colid column index for date-time. The default value is 1.
 #' @param inunit input's unit for VOC concentration. A character vector from these options: "ugm" or "ppbv". 
 #' "ugm" means ug/m3. "ppbv" means part per billion volumn. The default vaule is "ppbv".
 #' @param outunit output's unit for VOC concentration. A character from these options: "ugm" or "ppbv". 
@@ -27,8 +24,8 @@
 #' are sorted or not. By default, sortd has value "TRUE".
 #' If TRUE, VOC species in time series will be arranged according to VOC group,
 #'  relative molecular weight, and MIR value.
-#' @param colid column index for date-time. The default value is 1.
 #' @param chn logical. Dose colnames present as Chinese? The default vaule is FALSE.
+#' @param mtype text. "usa" for MIR value from USA, "chn" for MIR value from CHINA.
 #' @return  a list contains 5 tables:
 #' MIR_Result: matched MIR value result;
 #' OFP_Result: OFP time series of VOC by species;
@@ -37,19 +34,21 @@
 #' OFP_Result_group_mean: the average value and proportion of OFP of VOC according to major groups (sorted from large to small).
 #'
 #' @export
-#' @importFrom utils URLencode
-#' @importFrom utils download.file
-#' @importFrom xml2 read_html
-#' @importFrom rvest html_nodes html_text
+#' @examples
+#' ofp(voc)
 #' @import magrittr
 #' @importFrom stringr str_split_fixed
 
-ofp <- function(df, inunit = "ppbv", outunit = "ppbv", t = 25, p = 101.325, stcd=FALSE, sortd =TRUE, colid = 1, chn=FALSE){
+ofp <- function(df, inunit = "ppbv", outunit = "ppbv", t = 25, p = 101.325, stcd=FALSE, sortd =TRUE, chn=FALSE, mtype="usa"){
 
-  #set colid
-  if(colid != 1){
-    df[,c(1,colid)] = df[,c(colid,1)]
-    colnames(df)[c(1,colid)] = colnames(df)[c(colid,1)]
+  #generate datacasv2 according to datacas
+  datacasv2=datacas
+  if(mtype=="usa"){
+	datacasv2$MIR=datacasv2$New
+	datacasv2$MIR_type="USA"
+  }else{
+	datacasv2$MIR=datacasv2$mir_cn
+	datacasv2$MIR_type="CHINA"
   }
 
   #In case df is not a dataframe.
@@ -57,16 +56,7 @@ ofp <- function(df, inunit = "ppbv", outunit = "ppbv", t = 25, p = 101.325, stcd
   df <- data.frame(df,stringsAsFactors = FALSE)
   colnames(df) <- temp_col_name
 
-  if(chn==FALSE){  
-	  #In case df includes m,p-Xylene
-	  colnames_short = gsub("\\,|\\-| ", "", tolower(colnames(df)))
-	  if("mpxylene" %in% colnames_short){
-		  xyleneid=which(colnames_short %in% "mpxylene")
-		  df=df[,c(1:xyleneid,xyleneid:ncol(df))]
-		  df[,c(xyleneid,(xyleneid+1))]=df[,c(xyleneid,(xyleneid+1))]/2
-		  colnames(df)[c(xyleneid,(xyleneid+1))]=c("m-Xylene","p-Xylene")
-	  }
-	  
+  if(chn==FALSE){  	  
 	  #get VOC name by colnames of df
 	  #if read from xlsx, replace "X" and "."
 	  colnm_df = colnames(df)[2:ncol(df)]
@@ -76,91 +66,49 @@ ofp <- function(df, inunit = "ppbv", outunit = "ppbv", t = 25, p = 101.325, stcd
 	  chemicalnames = gsub("\\i-", "iso-", chemicalnames)
 
 	  #build name_df
-	  name_df = data.frame(name = chemicalnames,CAS = NA, Source = NA, Matched_Name = NA, MIR = NA, MW = NA, Group = NA, stringsAsFactors = FALSE)
+	  name_df = data.frame(name = chemicalnames,CAS = NA, Matched_Name = NA, MIR = NA, MIR_type = NA, MW = NA, Group = NA, stringsAsFactors = FALSE)
 
 	  #search VOC name to get CAS Number from different sources, add cas, sources, mathed_name to name_df
 	  ##firstly by NIST
 	  for( i in 1:nrow(name_df)){
-		str <- name_df[i,1]
-		str <- URLencode(str)
-		url=paste(c("https://webbook.nist.gov/cgi/cbook.cgi?Name=", str,"&Units=SI"), collapse='')
-		download.file(url, destfile = "scrapedpage.html", quiet=TRUE)
-		web <- read_html("scrapedpage.html")
-		result_test<-web%>%html_nodes("h1")%>%html_text()
-		if(result_test[2] == "Name Not Found"){
-		  name_df[i,2]="Name Not Found"
-		  name_df[i,3]=NA
-		}else if(result_test[2] == "Search Results"){
-		  name_df[i,2]="More than 1 result"
-		  name_df[i,3]=NA
-		}else if(grepl("structure unspecified",result_test[2])){
-		  name_df[i,2]="structure unspecified in NIST"
-		  name_df[i,3]=NA
-		}else{
-		  result_test<-web%>%html_nodes("li")%>%html_text()
-		  result_test<-strsplit(result_test[21], ": ")
-		  name_df[i,2]=result_test[[1]][2]
-		  name_df[i,3]="NIST"
+		tarname <- name_df[i,1]
+		#test if name can be matched by names
+		tarname=gsub("[^[:alnum:]]", "",tarname)
+		tarname=tolower(tarname)
+		tarid=eval(parse(text=paste0("grep('(?<![^;])",tarname,"(?![^;])',datacasv2$otn, value = FALSE, perl=TRUE)")))
+		#if no, test if name can be matched by names
+		if(length(tarid)!=1){
+			tarname <- name_df[i,1]
+			tarid=eval(parse(text=paste0("grep('(?<![^;])",tarname,"(?![^;])',datacasv2$CAS, value = FALSE, perl=TRUE)")))
 		}
-	  }
-	  file.remove("scrapedpage.html")
-
-	  #match mir by different sources
-	  ##get CAS from NIST, match name by CAS
-	  a=lapply(name_df$CAS[which(name_df$Source=="NIST"&!is.na(name_df$CAS))], function(i) grep(i, datacas$CAS))
-	  a=unlist(lapply(a,function(x) if(identical(x,integer(0))) ' ' else x))
-	  name_df$MIR[which(name_df$Source=="NIST"&!is.na(name_df$CAS))] = datacas$New[as.numeric(a)]
-	  name_df$Matched_Name[which(name_df$Source=="NIST"&!is.na(name_df$CAS))] = datacas$Description[as.numeric(a)]
-	  name_df$MW[which(name_df$Source=="NIST"&!is.na(name_df$CAS))] = datacas$MWt[as.numeric(a)]
-	  name_df$Group[which(name_df$Source=="NIST"&!is.na(name_df$CAS))] = datacas$Group[as.numeric(a)]
-
-
-	  #if it is matched by CAS in NIST and matched by name in Carter paper, but it doesn't have CAS in Carter paper.
-	  for(k in which(!is.na(name_df$Source)&is.na(name_df$MIR))){
-		tarlist=gsub(" ", "", tolower(datacas$Description), fixed = TRUE)
-		tar=gsub(" ", "", tolower(name_df$name[k]), fixed = TRUE)
-		df_null=data.frame(datacas[tarlist %in% tar,])
-		if(nrow(df_null)!=0){
-		  name_df$Matched_Name[as.numeric(k)] = df_null$Description[1]
-		  #name_df$CAS[as.numeric(k)] = df_null$CAS[1]
-		  name_df$MIR[as.numeric(k)] = df_null$New[1]
-		  name_df$Source[as.numeric(k)] = "CAS is found in NIST. But it only has name in Carter paper 2010"
-		  name_df$MW[as.numeric(k)] = df_null$MWt[1]
-		  name_df$Group[as.numeric(k)] = df_null$Group[1]
-		}
-	  }
-
-	  #if it isn't found in NIST, but its name is matched by Carter paper.
-	  for(k in which(is.na(name_df$Source))){
-		tarlist=gsub(" ", "", tolower(datacas$Description), fixed = TRUE)
-		tar=gsub(" ", "", tolower(name_df$name[k]), fixed = TRUE)
-		df_null=data.frame(datacas[tarlist %in% tar,])
-		if(nrow(df_null)!=0){
-		  name_df$Matched_Name[as.numeric(k)] = df_null$Description[1]
-		  name_df$CAS[as.numeric(k)] = df_null$CAS[1]
-		  name_df$MIR[as.numeric(k)] = df_null$New[1]
-		  name_df$Source[as.numeric(k)] = "Carter paper 2010"
-		  name_df$MW[as.numeric(k)] = df_null$MWt[1]
-		  name_df$Group[as.numeric(k)] = df_null$Group[1]
+		#if finally get tarid (match)
+		if(length(tarid)==1){
+			tarid=as.numeric(tarid)
+			name_df$CAS[i] = datacasv2$CAS[tarid]
+			name_df$Matched_Name[i] = datacasv2$Description[tarid]
+			name_df$MIR[i] = datacasv2$MIR[tarid]
+			name_df$MIR_type[i] = datacasv2$MIR_type[tarid]
+			name_df$MW[i] = datacasv2$MWt[tarid]
+			name_df$Group[i] = datacasv2$Group[tarid]
 		}
 	  }
 	}else{
 	  #build name_df
 	  colnm_df = colnames(df)[2:ncol(df)]
 	  chemicalnames = ifelse(substr(colnm_df, 1, 1) == "X", sub("^.", "", colnm_df), colnm_df)
-	  name_df = data.frame(name = chemicalnames,CAS = NA, Source = NA, Matched_Name = NA, MIR = NA, MW = NA, Group = NA, stringsAsFactors = FALSE)
+	  name_df = data.frame(name = chemicalnames,CAS = NA, Matched_Name = NA, MIR = NA, MIR_type = NA, MW = NA, Group = NA, stringsAsFactors = FALSE)
 	  #match table by chinese name
 
-	  chn_name_db<-data.frame(str_split_fixed(gsub("\\/|\\,|\\-| ", "", datacas$chn), ';', 3))#change according to max chinese name vector
+	  chn_name_db<-data.frame(str_split_fixed(gsub("\\/|\\,|\\-| ", "", datacasv2$chn), ';', 3))#change according to max chinese name vector
 	  for(k in 1:nrow(name_df)){
-		chn_df<-data.frame(str_split_fixed(gsub("\\,|\\-| ", "", datacas$chn), ';', 2))
+		chn_df<-data.frame(str_split_fixed(gsub("\\,|\\-| ", "", datacasv2$chn), ';', 2))
 		x=which(chn_df == gsub("\\,|\\,|\\-| ", "", name_df$name[k]), arr.ind = TRUE)[1]
-		df_null=data.frame(datacas[x,])
+		df_null=data.frame(datacasv2[x,])
 		if(nrow(df_null)!=0){
-		  name_df$Matched_Name[as.numeric(k)] = df_null$Description[1]
 		  name_df$CAS[as.numeric(k)] = df_null$CAS[1]
-		  name_df$MIR[as.numeric(k)] = df_null$New[1]
-		  name_df$Source[as.numeric(k)] = "Carter paper 2010"
+		  name_df$Matched_Name[as.numeric(k)] = df_null$Description[1]
+		  name_df$MIR[as.numeric(k)] = df_null$MIR[1]
+		  name_df$MIR_type[as.numeric(k)] = df_null$MIR_type[1]
 		  name_df$MW[as.numeric(k)] = df_null$MWt[1]
 		  name_df$Group[as.numeric(k)] = df_null$Group[1]
 		}
